==> webkit2gtk_2.48.6.orig.tar.xz: webkitgtk-2.48.6/Source/JavaScriptCore/heap/MarkingConstraintExecutorPair.h <==
/*
 * Copyright (C) 2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include <wtf/Function.h>

namespace JSC {

class AbstractSlotVisitor;
class SlotVisitor;

struct MarkingConstraintExecutorPair {
    MarkingConstraintExecutorPair(
        ::Function<void(AbstractSlotVisitor&)> abstractSlotVisitorFunc,
        ::Function<void(SlotVisitor&)> slotVisitorFunc)
        : abstractSlotVisitorFunc(WTFMove(abstractSlotVisitorFunc))
        , slotVisitorFunc(WTFMove(slotVisitorFunc))
    { }
    MarkingConstraintExecutorPair(MarkingConstraintExecutorPair&&) = default;

    void execute(AbstractSlotVisitor& visitor) { abstractSlotVisitorFunc(visitor); }
    void execute(SlotVisitor& visitor) { slotVisitorFunc(visitor); }

    ::Function<void(AbstractSlotVisitor&)> abstractSlotVisitorFunc;
    ::Function<void(SlotVisitor&)> slotVisitorFunc;
};

#define MAKE_MARKING_CONSTRAINT_EXECUTOR_PAIR(lambda) \
    MarkingConstraintExecutorPair((lambda), (lambda))

} // namespace JSC

==> webkit2gtk_2.51.90.orig.tar.xz: webkitgtk-2.51.90/Source/JavaScriptCore/heap/MarkingConstraintExecutorPair.h <==
/*
 * Copyright (C) 2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include <wtf/Function.h>

namespace JSC {

class AbstractSlotVisitor;
class SlotVisitor;

struct MarkingConstraintExecutorPair {
    MarkingConstraintExecutorPair(
        ::Function<void(AbstractSlotVisitor&)> abstractSlotVisitorFunc,
        ::Function<void(SlotVisitor&)> slotVisitorFunc)
        : abstractSlotVisitorFunc(WTF::move(abstractSlotVisitorFunc))
        , slotVisitorFunc(WTF::move(slotVisitorFunc))
    { }
    MarkingConstraintExecutorPair(MarkingConstraintExecutorPair&&) = default;

    void execute(AbstractSlotVisitor& visitor) { abstractSlotVisitorFunc(visitor); }
    void execute(SlotVisitor& visitor) { slotVisitorFunc(visitor); }

    ::Function<void(AbstractSlotVisitor&)> abstractSlotVisitorFunc;
    ::Function<void(SlotVisitor&)> slotVisitorFunc;
};

#define MAKE_MARKING_CONSTRAINT_EXECUTOR_PAIR(lambda) \
    MarkingConstraintExecutorPair((lambda), (lambda))

} // namespace JSC
